/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org view-source front-end.
 *
 * The Initial Developer of the Original Code is mozilla.org.
 * Portions created by the Initial Developer are Copyright (C) 2002
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Jeroen Groenenboom <jagrboom@zonnet.nl> (Original Author)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

var bMHPrefsWindow = {

init: function() {
	  var field;
	  var prefIndex;
	  // engine
	  field = document.getElementById( "engine" );
	  field.selectedIndex = bMHPrefs.getPref( "engine" );
	  // text fields
	  for( prefIndex = 1; prefIndex < bMHPrefs.defaults.length-1; prefIndex++ ) {
	      field = document.getElementById( bMHPrefs.defaults[prefIndex].name );
	      field.value = bMHPrefs.getPref( bMHPrefs.defaults[prefIndex].name );
	  }
	  // exclude folders
	  bMHPrefsWindow.writeExcludeDoc( bMHPrefs.getPref( "excludedFolders" ));
      },

writeExcludeDoc: function( excludeString ) {
		     var doc = excludeFrame.document;
		     var excludedFolders = excludeString.split( "|" ); 
		     doc.writeln( '<html>\n<body>\n<tt>\n<form id="excludeForm">' );

		     var hiddenForm = window.opener.document.getElementById( "hiddenFolderForm" );
		     inputs = hiddenForm.getElementsByTagName( "input" );
		     var ancestorsArray = new Array( inputs.length );
		     for( var i = 0; i < inputs.length; i++ ) {
			 ancestorsArray[i] = inputs[i].value;
		     }
		     ancestorsArray.sort();
		     var ancestors, isChecked, i, j;
		     for( i = 0; i < ancestorsArray.length; i++ ) { 
			 ancestors = ancestorsArray[i].split( "," );
			 for( j = 1; j < ancestors.length; j++ ) {
			     doc.write( '&nbsp;&nbsp;&nbsp;&nbsp;' );
			 }
			 isChecked = "";
			 // excludedFolders is sorted
			 if( bMHPrefs.binarySearch( ancestorsArray[i], excludedFolders ) >= 0 ) {
			     isChecked = "checked";
			 }
			 doc.writeln( '\n<input type="checkbox" name="excludeCheckbox"' +
				 isChecked + '" value="' + ancestorsArray[i] + '">' + 
				 ancestors[ancestors.length-1] + '<br>' );
		     }
		     doc.writeln( '\n</form>\n</tt>\n</body>\n</html>' );
		     doc.close();
		 },

reset: function() {
	   var field;
	   var prefIndex = 0;
	   // engine
	   field = document.getElementById( "engine" );
	   field.selectedIndex = bMHPrefs.defaults[prefIndex].value;
	   // text fields
	   for( prefIndex = 1; prefIndex < bMHPrefs.defaults.length-1; prefIndex++ ) {
	       field = document.getElementById( bMHPrefs.defaults[prefIndex].name );
	       field.value = bMHPrefs.defaults[prefIndex].value;
	   }
	   // exclude folders
	   bMHPrefsWindow.writeExcludeDoc( bMHPrefs.defaults[prefIndex].value );
       },

close: function() {
	    window.close();
	},

apply: function() {
	  var prefs = new Array( bMHPrefs.defaults.length );
	  var prefIndex = 0;
	  var field, type, value;
	  // engine
	  field = document.getElementById( "engine" ),
	  value = field.selectedIndex;
	  prefs[prefIndex] = { name: "engine", type: 64, value: value };
	  // text fields
	  for( prefIndex = 1; prefIndex < prefs.length-1; prefIndex++ ) {
	      field = document.getElementById( bMHPrefs.defaults[prefIndex].name );
	      type = bMHPrefs.defaults[prefIndex].type;
	      value = bMHPrefsWindow.parseValue( field.value, bMHPrefs.defaults[prefIndex] ); 
	      prefs[prefIndex] = { name: field.id, type: type, value: value };
	      if( value == -1 ) {
		  alert( field.id + ' does not have a proper value' );
		  return;
	      }
	  }
	  // exclude folders
	  var excludeString = "";
	  var checkboxes = excludeFrame.document.getElementsByName( "excludeCheckbox" );
	  for( var i = 0; i < checkboxes.length; i++ ) {
	      if( checkboxes[i].checked ) {
		  excludeString += ( "|" + checkboxes[i].value );
	      }
	  }
	  if( excludeString.length > 0 ) {
	      // remove first bar
	      excludeString = excludeString.substr( 1 );
	  }
	  prefs[prefIndex] = { name: "excludedFolders", type: 32, value: excludeString };
	  // set preferences
	  for( prefIndex = 0; prefIndex < prefs.length; prefIndex++ ) {
	      bMHPrefs.setPref( prefs[prefIndex].name, prefs[prefIndex].type, prefs[prefIndex].value );
	  }
	  window.opener.location.reload();
},

parseValue: function( value, dflt ) {
		if( dflt.type == 64 ) {
		    value = parseInt( value );
		    if( isNaN( value ) ||
			    value < 0 ||
			    ( value == 0 && 
			      (dflt.name == "nrOfColumns" || 
			       dflt.name == "maxNameLength" ))) {
			return -1;
		    }
		}
		return value;
	    },
}



